# eco-connect @ Ecorithm
A wrapper for connecting to Ecorithm's API Platform through python

[![Build Status](https://travis-ci.org/ecorithm/eco-connect.svg?branch=master)](https://travis-ci.org/ecorithm/eco-connect)
[![Coverage Status](https://coveralls.io/repos/github/ecorithm/eco-connect/badge.svg?branch=master&t=RDCkPJ)](https://coveralls.io/github/ecorithm/eco-connect?branch=master)

## Documentation
- http://eco-connect.readthedocs.io/en/latest/index.html
